@@ -1,4 +1,3 @@
-#! __ATF_SH__
 # Copyright 2012 Google Inc.
 # All rights reserved.
 #
@@ -27,9 +26,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-
-# Path to a local cvsroot for testing purposes.
-MOCK_CVSROOT=":local:$(pwd)/cvsroot"
+shtk_import unittest
 
 
 # Paths to installed files.
@@ -79,7 +76,7 @@ EOF
 create_mock_cvsroot() {
     local repository="${1}"; shift
 
-    atf_check -o ignore -e ignore cvs -d "${repository}" init
+    assert_command -o ignore -e ignore cvs -d "${repository}" init
 
     mkdir src
     cd src
@@ -98,27 +95,29 @@ create_mock_cvsroot() {
 }
 
 
-atf_test_case build__custom_dirs
-build__custom_dirs_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__custom_dirs
+build__custom_dirs_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
     cat >test.conf <<EOF
 BUILD_ROOT=$(pwd)/b
-CVSROOT=${MOCK_CVSROOT}
+CVSROOT=${mock_cvsroot}
 RELEASEDIR=$(pwd)/r
 SRCDIR=$(pwd)/s
 XSRCDIR=$(pwd)/x
 EOF
 
-    atf_check -o save:stdout -e save:stderr sysbuild -c test.conf build
+    SHTK_HW_NCPUS=1 assert_command -o save:stdout -e save:stderr \
+        sysbuild -c test.conf build
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: cvs
 Directory: ${HOME}/s/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -126,7 +125,7 @@ Arg: src
 
 Command: cvs
 Directory: ${HOME}/x/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -146,24 +145,24 @@ Arg: -x
 Arg: release
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case build__defaults
-build__defaults_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__defaults
+build__defaults_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" build
+    SHTK_HW_NCPUS=1 assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" build
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: cvs
 Directory: ${HOME}/sysbuild/src/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -181,16 +180,16 @@ Arg: -m$(uname -m)
 Arg: release
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case build__remove_all
-build__remove_all_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__remove_all
+build__remove_all_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     mkdir sysbuild
     cd sysbuild
-    atf_check -o ignore -e ignore cvs -d"${MOCK_CVSROOT}" checkout -P src
+    assert_command -o ignore -e ignore cvs -d"${mock_cvsroot}" checkout -P src
     cd -
 
     create_mock_binary cvs
@@ -201,22 +200,23 @@ build__remove_all_body() {
     mkdir -p "sysbuild/$(uname -m)/tools/c"
     mkdir -p "sysbuild/$(uname -m)/keep-me"
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" build
+    assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" build
 
-    [ ! -d "sysbuild/$(uname -m)/destdir" ] || atf_fail "destdir not removed"
-    [ ! -d "sysbuild/$(uname -m)/obj" ] || atf_fail "obj not removed"
-    [ ! -d "sysbuild/$(uname -m)/tools" ] || atf_fail "tools not removed"
-    [ -d "sysbuild/$(uname -m)/keep-me" ] || atf_fail "All of buildroot removed"
+    [ ! -d "sysbuild/$(uname -m)/destdir" ] || fail "destdir not removed"
+    [ ! -d "sysbuild/$(uname -m)/obj" ] || fail "obj not removed"
+    [ ! -d "sysbuild/$(uname -m)/tools" ] || fail "tools not removed"
+    [ -d "sysbuild/$(uname -m)/keep-me" ] || fail "All of buildroot removed"
 }
 
 
-atf_test_case build__fast_mode
-build__fast_mode_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__fast_mode
+build__fast_mode_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     mkdir sysbuild
     cd sysbuild
-    atf_check -o ignore -e ignore cvs -d"${MOCK_CVSROOT}" checkout -P src
+    assert_command -o ignore -e ignore cvs -d"${mock_cvsroot}" checkout -P src
     cd -
 
     create_mock_binary cvs
@@ -225,10 +225,10 @@ build__fast_mode_body() {
     mkdir -p "sysbuild/$(uname -m)/destdir/bin"
     mkdir -p "sysbuild/$(uname -m)/destdir/stand/$(uname -m)/1.2.3"
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" build -f
+    SHTK_HW_NCPUS=1 assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" build -f
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: build.sh
 Directory: ${HOME}/sysbuild/src
 Arg: -D${HOME}/sysbuild/$(uname -m)/destdir
@@ -242,30 +242,30 @@ Arg: -u
 Arg: release
 
 EOF
-    atf_check -o file:expout cat commands.log
 
     [ -d "sysbuild/$(uname -m)/destdir/bin" ] \
-        || atf_fail "Deleted a directory that should not have been deleted"
+        || fail "Deleted a directory that should not have been deleted"
     [ ! -d "sysbuild/$(uname -m)/destdir/stand/$(uname -m)/1.2.3" ] \
-        || atf_fail "Obsolete modules not deleted"
+        || fail "Obsolete modules not deleted"
 }
 
 
-atf_test_case build__many_machines
-build__many_machines_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__many_machines
+build__many_machines_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" \
+    assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" \
         -o MACHINES="amd64 macppc shark" -o NJOBS=2 build
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: cvs
 Directory: ${HOME}/sysbuild/src/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -308,26 +308,26 @@ Arg: -mshark
 Arg: release
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case build__machine_targets__ok
-build__machine_targets__ok_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__machine_targets__ok
+build__machine_targets__ok_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" \
+    assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" \
         -o MACHINES="amd64 macppc shark" -o NJOBS=2 build \
         tools macppc:kernel=/foo/bar shark:sets release
-cat stdout
-    cat >expout <<EOF
+
+    assert_file stdin commands.log <<EOF
 Command: cvs
 Directory: ${HOME}/sysbuild/src/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -375,37 +375,104 @@ Arg: sets
 Arg: release
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case build__machine_targets__unmatched
-build__machine_targets__unmatched_body() {
+shtk_unittest_add_test build__machine_arch_targets__ok
+build__machine_arch_targets__ok_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
+
+    create_mock_binary cvs yes
+    PATH="$(pwd):${PATH}"
+
+    assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" \
+        -o MACHINES="evbarm-aarch64 evbarm-earmv7hf fake-multi-dashes" \
+        -o NJOBS=2 build evbarm-aarch64:sets release
+
+    assert_file stdin commands.log <<EOF
+Command: cvs
+Directory: ${HOME}/sysbuild/src/.cvs-checkout
+Arg: -d${mock_cvsroot}
+Arg: -q
+Arg: checkout
+Arg: -P
+Arg: src
+
+Command: build.sh
+Directory: ${HOME}/sysbuild/src
+Arg: -D${HOME}/sysbuild/evbarm-aarch64/destdir
+Arg: -M${HOME}/sysbuild/evbarm-aarch64/obj
+Arg: -N2
+Arg: -R${HOME}/sysbuild/release
+Arg: -T${HOME}/sysbuild/evbarm-aarch64/tools
+Arg: -U
+Arg: -j2
+Arg: -aaarch64
+Arg: -mevbarm
+Arg: sets
+Arg: release
+
+Command: build.sh
+Directory: ${HOME}/sysbuild/src
+Arg: -D${HOME}/sysbuild/evbarm-earmv7hf/destdir
+Arg: -M${HOME}/sysbuild/evbarm-earmv7hf/obj
+Arg: -N2
+Arg: -R${HOME}/sysbuild/release
+Arg: -T${HOME}/sysbuild/evbarm-earmv7hf/tools
+Arg: -U
+Arg: -j2
+Arg: -aearmv7hf
+Arg: -mevbarm
+Arg: release
+
+Command: build.sh
+Directory: ${HOME}/sysbuild/src
+Arg: -D${HOME}/sysbuild/fake-multi-dashes/destdir
+Arg: -M${HOME}/sysbuild/fake-multi-dashes/obj
+Arg: -N2
+Arg: -R${HOME}/sysbuild/release
+Arg: -T${HOME}/sysbuild/fake-multi-dashes/tools
+Arg: -U
+Arg: -j2
+Arg: -amulti-dashes
+Arg: -mfake
+Arg: release
+
+EOF
+}
+
+
+shtk_unittest_add_test build__machine_targets__unmatched
+build__machine_targets__unmatched_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
     cat >experr <<EOF
 sysbuild: E: The 'macpp:kernel=/foo/bar a:b' targets do not match any machine in 'amd64 macppc shark'
 EOF
-    atf_check -s exit:1 -o empty -e file:experr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" \
+    assert_command -s exit:1 -o empty -e file:experr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" \
         -o MACHINES="amd64 macppc shark" -o NJOBS=2 build \
         tools macpp:kernel=/foo/bar a:b release
 
-    test ! -f commands.log || atf_fail "cvs should not have been executed"
+    test ! -f commands.log || fail "cvs should not have been executed"
 }
 
 
-atf_test_case build__mkvars
-build__mkvars_body() {
+shtk_unittest_add_test build__mkvars
+build__mkvars_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
     mkdir -p sysbuild/src
     create_mock_binary sysbuild/src/build.sh
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" \
+    SHTK_HW_NCPUS=1 assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" \
         -o MKVARS="MKDEBUG=yes FOO=bar" build -f
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: build.sh
 Directory: ${HOME}/sysbuild/src
 Arg: -D${HOME}/sysbuild/$(uname -m)/destdir
@@ -421,25 +488,25 @@ Arg: -u
 Arg: release
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case build__with_x11
-build__with_x11_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__with_x11
+build__with_x11_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" \
+    SHTK_HW_NCPUS=1 assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" \
         -o XSRCDIR="${HOME}/sysbuild/xsrc" build
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: cvs
 Directory: ${HOME}/sysbuild/src/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -447,7 +514,7 @@ Arg: src
 
 Command: cvs
 Directory: ${HOME}/sysbuild/xsrc/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -467,24 +534,24 @@ Arg: -x
 Arg: release
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case build__some_args
-build__some_args_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__some_args
+build__some_args_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
-    atf_check -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" build a foo b
+    SHTK_HW_NCPUS=1 assert_command -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" build a foo b
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: cvs
 Directory: ${HOME}/sysbuild/src/.cvs-checkout
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: checkout
 Arg: -P
@@ -504,19 +571,19 @@ Arg: foo
 Arg: b
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case build__hooks__ok
-build__hooks__ok_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__hooks__ok
+build__hooks__ok_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 MACHINES="one two"  # Build hooks are only supposed to be called once.
 SRCDIR="$(pwd)/checkout/src"
 
@@ -537,8 +604,8 @@ post_build_hook() {
 }
 EOF
 
-    atf_check -o save:stdout -e save:stderr sysbuild -c test.conf build
-    grep 'Command: build.sh' commands.log || atf_fail "build.sh not run"
+    assert_command -o save:stdout -e save:stderr sysbuild -c test.conf build
+    grep 'Command: build.sh' commands.log || fail "build.sh not run"
 
     cat >exp_order <<EOF
 Hook before fetch: $(pwd)/checkout/src
@@ -546,15 +613,16 @@ Hook after fetch
 Hook before build: one two
 Hook after build
 EOF
-    atf_check -o file:exp_order grep '^Hook' stdout
+    assert_command -o file:exp_order grep '^Hook' stdout
 }
 
 
-atf_test_case build__hooks__pre_fail
-build__hooks__pre_fail_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__hooks__pre_fail
+build__hooks__pre_fail_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 
 pre_fetch_hook() {
@@ -575,10 +643,10 @@ post_build_hook() {
 }
 EOF
 
-    atf_check -s exit:1 -o save:stdout -e save:stderr \
+    assert_command -s exit:1 -o save:stdout -e save:stderr \
         sysbuild -c test.conf build
     if grep 'Command: build.sh' commands.log; then
-        atf_fail "build.sh should not have been run"
+        fail "build.sh should not have been run"
     fi
 
     cat >exp_order <<EOF
@@ -586,15 +654,16 @@ Hook before fetch
 Hook after fetch
 Hook before build
 EOF
-    atf_check -o file:exp_order grep '^Hook' stdout
+    assert_command -o file:exp_order grep '^Hook' stdout
 }
 
 
-atf_test_case build__hooks__post_fail
-build__hooks__post_fail_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__hooks__post_fail
+build__hooks__post_fail_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 
 pre_build_hook() {
@@ -607,36 +676,37 @@ post_build_hook() {
 }
 EOF
 
-    atf_check -s exit:1 -o save:stdout -e save:stderr \
+    assert_command -s exit:1 -o save:stdout -e save:stderr \
         sysbuild -c test.conf build
-    grep 'Command: build.sh' commands.log || atf_fail "build.sh not run"
+    grep 'Command: build.sh' commands.log || fail "build.sh not run"
 
     cat >exp_order <<EOF
 Hook before build
 Hook after build
 EOF
-    atf_check -o file:exp_order grep '^Hook' stdout
+    assert_command -o file:exp_order grep '^Hook' stdout
 }
 
 
-atf_test_case build__cvs_fails
-build__cvs_fails_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test build__cvs_fails
+build__cvs_fails_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     mkdir sysbuild
     cd sysbuild
-    atf_check -o ignore -e ignore cvs -d"${MOCK_CVSROOT}" checkout -P src
+    assert_command -o ignore -e ignore cvs -d"${mock_cvsroot}" checkout -P src
     cd -
 
     create_mock_binary cvs yes
     PATH="$(pwd):${PATH}"
 
-    atf_check -s exit:1 -o save:stdout -e save:stderr sysbuild \
-        -c /dev/null -o CVSROOT="${MOCK_CVSROOT}" -o CVSTAG=invalid build
+    assert_command -s exit:1 -o save:stdout -e save:stderr sysbuild \
+        -c /dev/null -o CVSROOT="${mock_cvsroot}" -o CVSTAG=invalid build
 
-    cat >expout <<EOF
+    assert_file stdin commands.log <<EOF
 Command: cvs
 Directory: ${HOME}/sysbuild/src
-Arg: -d${MOCK_CVSROOT}
+Arg: -d${mock_cvsroot}
 Arg: -q
 Arg: update
 Arg: -d
@@ -644,12 +714,21 @@ Arg: -P
 Arg: -rinvalid
 
 EOF
-    atf_check -o file:expout cat commands.log
 }
 
 
-atf_test_case config__builtins
-config__builtins_body() {
+shtk_unittest_add_test build__unknown_flag
+build__unknown_flag_test() {
+cat >experr <<EOF
+sysbuild: E: Unknown option -Z in build
+Type 'man sysbuild' for help
+EOF
+    assert_command -s exit:1 -e file:experr sysbuild -c /dev/null build -f -Z
+}
+
+
+shtk_unittest_add_test config__builtins
+config__builtins_test() {
     cat >expout <<EOF
 BUILD_ROOT = ${HOME}/sysbuild
 BUILD_TARGETS = release
@@ -658,63 +737,64 @@ CVSTAG is undefined
 INCREMENTAL_BUILD = false
 MACHINES = $(uname -m)
 MKVARS is undefined
-NJOBS is undefined
+NJOBS = 123
 RELEASEDIR = ${HOME}/sysbuild/release
 SRCDIR = ${HOME}/sysbuild/src
 UPDATE_SOURCES = true
 XSRCDIR is undefined
 EOF
-    atf_check -o file:expout sysbuild -c /dev/null config
+    SHTK_HW_NCPUS=123 assert_command -o file:expout sysbuild -c /dev/null config
 }
 
 
-atf_test_case config__path__components
-config__path__components_body() {
+shtk_unittest_add_test config__path__components
+config__path__components_test() {
     mkdir .sysbuild
     mkdir system
     export SYSBUILD_ETCDIR="$(pwd)/system"
 
     echo "BUILD_TARGETS=foo" >my-file
-    atf_check -o match:"BUILD_TARGETS = foo" sysbuild -c ./my-file config
+    assert_command -o match:"BUILD_TARGETS = foo" sysbuild -c ./my-file config
 }
 
 
-atf_test_case config__path__extension
-config__path__extension_body() {
+shtk_unittest_add_test config__path__extension
+config__path__extension_test() {
     mkdir .sysbuild
     mkdir system
     export SYSBUILD_ETCDIR="$(pwd)/system"
 
     echo "BUILD_TARGETS=bar" >my-file.conf
-    atf_check -o match:"BUILD_TARGETS = bar" sysbuild -c my-file.conf config
+    assert_command -o match:"BUILD_TARGETS = bar" sysbuild -c my-file.conf \
+        config
 }
 
 
-atf_test_case config__name__system_directory
-config__name__system_directory_body() {
+shtk_unittest_add_test config__name__system_directory
+config__name__system_directory_test() {
     mkdir .sysbuild
     mkdir system
     export SYSBUILD_ETCDIR="$(pwd)/system"
 
     echo "BUILD_TARGETS='some value'" >system/foo.conf
-    atf_check -o match:"BUILD_TARGETS = some value" sysbuild -c foo config
+    assert_command -o match:"BUILD_TARGETS = some value" sysbuild -c foo config
 }
 
 
-atf_test_case config__name__user_directory
-config__name__user_directory_body() {
+shtk_unittest_add_test config__name__user_directory
+config__name__user_directory_test() {
     mkdir .sysbuild
     mkdir system
     export SYSBUILD_ETCDIR="$(pwd)/system"
 
     echo "BUILD_TARGETS='some value'" >system/foo.conf
     echo "BUILD_TARGETS='other value'" >.sysbuild/foo.conf
-    atf_check -o match:"BUILD_TARGETS = other value" sysbuild -c foo config
+    assert_command -o match:"BUILD_TARGETS = other value" sysbuild -c foo config
 }
 
 
-atf_test_case config__name__not_found
-config__name__not_found_body() {
+shtk_unittest_add_test config__name__not_found
+config__name__not_found_test() {
     mkdir .sysbuild
     mkdir system
     export SYSBUILD_ETCDIR="$(pwd)/system"
@@ -723,12 +803,12 @@ config__name__not_found_body() {
 sysbuild: E: Cannot locate configuration named 'foobar'
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -o empty -e file:experr sysbuild -c foobar config
+    assert_command -s exit:1 -o empty -e file:experr sysbuild -c foobar config
 }
 
 
-atf_test_case config__overrides
-config__overrides_body() {
+shtk_unittest_add_test config__overrides
+config__overrides_test() {
     cat >custom.conf <<EOF
 BUILD_ROOT=/tmp/test
 CVSTAG=the-tag-override
@@ -742,29 +822,29 @@ CVSTAG = the-new-tag
 INCREMENTAL_BUILD = false
 MACHINES = $(uname -m)
 MKVARS is undefined
-NJOBS is undefined
+NJOBS = 88
 RELEASEDIR = ${HOME}/sysbuild/release
 SRCDIR is undefined
 UPDATE_SOURCES = true
 XSRCDIR is undefined
 EOF
-    atf_check -o file:expout sysbuild -c custom.conf -o CVSROOT="foo bar" \
-        -o CVSTAG=the-new-tag -o SRCDIR= config
+    SHTK_HW_NCPUS=99 assert_command -o file:expout sysbuild -c custom.conf \
+        -o CVSROOT="foo bar" -o CVSTAG=the-new-tag -o NJOBS=88 -o SRCDIR= config
 }
 
 
-atf_test_case config__too_many_args
-config__too_many_args_body() {
+shtk_unittest_add_test config__too_many_args
+config__too_many_args_test() {
     cat >experr <<EOF
 sysbuild: E: config does not take any arguments
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -e file:experr sysbuild -c /dev/null config foo
+    assert_command -s exit:1 -e file:experr sysbuild -c /dev/null config foo
 }
 
 
-atf_test_case env__src_only
-env__src_only_body() {
+shtk_unittest_add_test env__src_only
+env__src_only_test() {
     cat >expout <<EOF
 . "${SYSBUILD_SHAREDIR}/env.sh" ;
 PATH="/my/root/shark/tools/bin:\${PATH}"
@@ -773,13 +853,13 @@ O="/my/root/shark/obj/usr/src"
 S="/usr/src"
 T="/my/root/shark/tools"
 EOF
-    atf_check -s exit:0 -o file:expout sysbuild -c /dev/null \
+    assert_command -s exit:0 -o file:expout sysbuild -c /dev/null \
         -o BUILD_ROOT=/my/root -o MACHINES=shark -o SRCDIR=/usr/src env
 }
 
 
-atf_test_case env__src_and_xsrc
-env__src_and_xsrc_body() {
+shtk_unittest_add_test env__src_and_xsrc
+env__src_and_xsrc_test() {
     cat >expout <<EOF
 . "${SYSBUILD_SHAREDIR}/env.sh" ;
 PATH="/my/root/i386/tools/bin:\${PATH}"
@@ -790,14 +870,14 @@ T="/my/root/i386/tools"
 XO="/my/root/i386/obj/d/xsrc"
 XS="/d/xsrc"
 EOF
-    atf_check -s exit:0 -o file:expout sysbuild -c /dev/null \
+    assert_command -s exit:0 -o file:expout sysbuild -c /dev/null \
         -o BUILD_ROOT=/my/root -o MACHINES=i386 -o SRCDIR=/a/b/src \
         -o XSRCDIR=/d/xsrc env
 }
 
 
-atf_test_case env__explicit_machine
-env__explicit_machine_body() {
+shtk_unittest_add_test env__explicit_machine
+env__explicit_machine_test() {
     cat >expout <<EOF
 . "${SYSBUILD_SHAREDIR}/env.sh" ;
 PATH="/my/root/macppc/tools/bin:\${PATH}"
@@ -806,14 +886,30 @@ O="/my/root/macppc/obj/usr/src"
 S="/usr/src"
 T="/my/root/macppc/tools"
 EOF
-    atf_check -s exit:0 -o file:expout sysbuild -c /dev/null \
+    assert_command -s exit:0 -o file:expout sysbuild -c /dev/null \
         -o BUILD_ROOT=/my/root -o MACHINES="amd64 i386" -o SRCDIR=/usr/src \
         env macppc
 }
 
 
-atf_test_case env__eval
-env__eval_body() {
+shtk_unittest_add_test env__explicit_machine_arch
+env__explicit_machine_arch_test() {
+    cat >expout <<EOF
+. "${SYSBUILD_SHAREDIR}/env.sh" ;
+PATH="/my/root/evbarm-aarch64/tools/bin:\${PATH}"
+D="/my/root/evbarm-aarch64/destdir"
+O="/my/root/evbarm-aarch64/obj/usr/src"
+S="/usr/src"
+T="/my/root/evbarm-aarch64/tools"
+EOF
+    assert_command -s exit:0 -o file:expout sysbuild -c /dev/null \
+        -o BUILD_ROOT=/my/root -o MACHINES="amd64 evbarm evbarm:aarch64 i386" \
+        -o SRCDIR=/usr/src env evbarm-aarch64
+}
+
+
+shtk_unittest_add_test env__eval
+env__eval_test() {
     make_one() {
         mkdir -p "${1}"
         touch "${1}/${2}"
@@ -834,7 +930,7 @@ echo "This is nbmake!"
 EOF
     chmod +x root/mach/tools/bin/nbmake-mach
 
-    atf_check -s exit:0 -o save:env.sh sysbuild -c /dev/null \
+    assert_command -s exit:0 -o save:env.sh sysbuild -c /dev/null \
         -o BUILD_ROOT="$(pwd)/root" \
         -o MACHINES="mach" \
         -o SRCDIR="$(pwd)/src" \
@@ -843,91 +939,94 @@ EOF
 
     eval $(cat ./env.sh)
 
-    [ -f "${D}/destdir.cookie" ] || atf_fail "D points to the wrong place"
-    [ -f "${O}/src-obj.cookie" ] || atf_fail "O points to the wrong place"
-    [ -f "${S}/src.cookie" ] || atf_fail "S points to the wrong place"
-    [ -f "${T}/tools.cookie" ] || atf_fail "T points to the wrong place"
-    [ -f "${XO}/xsrc-obj.cookie" ] || atf_fail "XO points to the wrong place"
-    [ -f "${XS}/xsrc.cookie" ] || atf_fail "XS points to the wrong place"
-    atf_check -o inline:"This is nbmake!\n" nbmake-mach
+    [ -f "${D}/destdir.cookie" ] || fail "D points to the wrong place"
+    [ -f "${O}/src-obj.cookie" ] || fail "O points to the wrong place"
+    [ -f "${S}/src.cookie" ] || fail "S points to the wrong place"
+    [ -f "${T}/tools.cookie" ] || fail "T points to the wrong place"
+    [ -f "${XO}/xsrc-obj.cookie" ] || fail "XO points to the wrong place"
+    [ -f "${XS}/xsrc.cookie" ] || fail "XS points to the wrong place"
+    assert_command -o inline:"This is nbmake!\n" nbmake-mach
 
     mkdir -p src/bin/ls
-    atf_check_equal '$(pwd)/root/mach/obj$(pwd)/src/bin/ls' \
-        '$(cd src/bin/ls && curobj)'
+    assert_equal "$(pwd)/root/mach/obj$(pwd)/src/bin/ls" \
+        "$(cd src/bin/ls && curobj)"
 
     mkdir -p xsrc/some/other/dir
-    atf_check_equal '$(pwd)/root/mach/obj$(pwd)/xsrc/some/other/dir' \
-        '$(cd xsrc/some/other/dir && curobj)'
+    assert_equal "$(pwd)/root/mach/obj$(pwd)/xsrc/some/other/dir" \
+        "$(cd xsrc/some/other/dir && curobj)"
 
     mkdir a
-    atf_check_equal 'NOT-FOUND' '$(cd a && curobj)'
-    atf_check_equal 'NOT-FOUND' '$(cd /bin && curobj)'
+    assert_equal "NOT-FOUND" "$(cd a && curobj)"
+    assert_equal "NOT-FOUND" "$(cd /bin && curobj)"
 }
 
 
-atf_test_case env__too_many_machines
-env__too_many_machines_body() {
+shtk_unittest_add_test env__too_many_machines
+env__too_many_machines_test() {
     cat >experr <<EOF
 sysbuild: E: No machine name provided as an argument and MACHINES contains more than one name
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -e file:experr sysbuild -c /dev/null \
+    assert_command -s exit:1 -e file:experr sysbuild -c /dev/null \
         -o MACHINES="amd64 i386" env
 }
 
 
-atf_test_case env__too_many_args
-env__too_many_args_body() {
+shtk_unittest_add_test env__too_many_args
+env__too_many_args_test() {
     cat >experr <<EOF
 sysbuild: E: env takes zero or one arguments
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -e file:experr sysbuild -c /dev/null env foo bar
+    assert_command -s exit:1 -e file:experr sysbuild -c /dev/null env foo bar
 }
 
 
-atf_test_case fetch__checkout__src_only
-fetch__checkout__src_only_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test fetch__checkout__src_only
+fetch__checkout__src_only_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 XSRCDIR=
 EOF
 
-    atf_check -o ignore -e not-match:"xsrc" sysbuild -c test.conf fetch
-    test -f checkout/src/file-in-src || atf_fail "src not checked out"
-    test ! -d checkout/xsrc || atf_fail "xsrc checked out but not requested"
+    assert_command -o ignore -e not-match:"xsrc" sysbuild -c test.conf fetch
+    test -f checkout/src/file-in-src || fail "src not checked out"
+    test ! -d checkout/xsrc || fail "xsrc checked out but not requested"
 }
 
 
-atf_test_case fetch__checkout__src_and_xsrc
-fetch__checkout__src_and_xsrc_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test fetch__checkout__src_and_xsrc
+fetch__checkout__src_and_xsrc_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 XSRCDIR="$(pwd)/checkout/xsrc"
 EOF
 
-    atf_check -o ignore -e ignore sysbuild -c test.conf fetch
-    test -f checkout/src/file-in-src || atf_fail "src not checked out"
-    test -f checkout/xsrc/file-in-xsrc || atf_fail "xsrc not checked out"
+    assert_command -o ignore -e ignore sysbuild -c test.conf fetch
+    test -f checkout/src/file-in-src || fail "src not checked out"
+    test -f checkout/xsrc/file-in-xsrc || fail "xsrc not checked out"
 }
 
 
-atf_test_case fetch__update__src_only
-fetch__update__src_only_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test fetch__update__src_only
+fetch__update__src_only_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 XSRCDIR=
 EOF
 
     mkdir checkout
     cd checkout
-    atf_check -o ignore -e ignore cvs -d"${MOCK_CVSROOT}" checkout -P src
+    assert_command -o ignore -e ignore cvs -d"${mock_cvsroot}" checkout -P src
     cd -
 
     cp -rf checkout/src src-copy
@@ -936,31 +1035,33 @@ EOF
     cvs commit -m "Second revision."
     cd -
 
-    test -f checkout/src/file-in-src || atf_fail "src not present yet"
+    test -f checkout/src/file-in-src || fail "src not present yet"
     if grep "second revision" checkout/src/file-in-src >/dev/null; then
-        atf_fail "second revision already present"
+        fail "second revision already present"
     fi
 
-    atf_check -o ignore -e not-match:"xsrc" sysbuild -c test.conf fetch
+    assert_command -o ignore -e not-match:"xsrc" sysbuild -c test.conf fetch
 
     grep "second revision" checkout/src/file-in-src >/dev/null \
-        || atf_fail "src not updated"
-    test ! -d checkout/xsrc || atf_fail "xsrc checked out but not requested"
+        || fail "src not updated"
+    test ! -d checkout/xsrc || fail "xsrc checked out but not requested"
 }
 
 
-atf_test_case fetch__update__src_and_xsrc
-fetch__update__src_and_xsrc_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test fetch__update__src_and_xsrc
+fetch__update__src_and_xsrc_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 XSRCDIR="$(pwd)/checkout/xsrc"
 EOF
 
     mkdir checkout
     cd checkout
-    atf_check -o ignore -e ignore cvs -d"${MOCK_CVSROOT}" checkout -P src xsrc
+    assert_command -o ignore -e ignore cvs -d"${mock_cvsroot}" checkout \
+        -P src xsrc
     cd -
 
     cp -rf checkout/src src-copy
@@ -975,29 +1076,30 @@ EOF
     cvs commit -m "Second revision."
     cd -
 
-    test -f checkout/src/file-in-src || atf_fail "src not present yet"
+    test -f checkout/src/file-in-src || fail "src not present yet"
     if grep "second revision" checkout/src/file-in-src >/dev/null; then
-        atf_fail "second revision already present"
+        fail "second revision already present"
     fi
-    test -f checkout/xsrc/file-in-xsrc || atf_fail "xsrc not present yet"
+    test -f checkout/xsrc/file-in-xsrc || fail "xsrc not present yet"
     if grep "second revision" checkout/xsrc/file-in-xsrc >/dev/null; then
-        atf_fail "second revision already present"
+        fail "second revision already present"
     fi
 
-    atf_check -o ignore -e ignore sysbuild -c test.conf fetch
+    assert_command -o ignore -e ignore sysbuild -c test.conf fetch
 
     grep "second revision" checkout/src/file-in-src >/dev/null \
-        || atf_fail "src not updated"
+        || fail "src not updated"
     grep "second revision" checkout/xsrc/file-in-xsrc >/dev/null \
-        || atf_fail "xsrc not updated"
+        || fail "xsrc not updated"
 }
 
 
-atf_test_case fetch__hooks__ok
-fetch__hooks__ok_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test fetch__hooks__ok
+fetch__hooks__ok_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 XSRCDIR="$(pwd)/checkout/xsrc"
 
@@ -1012,23 +1114,24 @@ post_fetch_hook() {
 }
 EOF
 
-    atf_check -o save:stdout -e ignore sysbuild -c test.conf fetch
-    test -f checkout/src/file-in-src || atf_fail "src not checked out"
-    test -f checkout/xsrc/file-in-xsrc || atf_fail "xsrc not checked out"
+    assert_command -o save:stdout -e ignore sysbuild -c test.conf fetch
+    test -f checkout/src/file-in-src || fail "src not checked out"
+    test -f checkout/xsrc/file-in-xsrc || fail "xsrc not checked out"
 
     cat >exp_order <<EOF
-Hook before fetch: ${MOCK_CVSROOT}
+Hook before fetch: ${mock_cvsroot}
 Hook after fetch
 EOF
-    atf_check -o file:exp_order grep '^Hook' stdout
+    assert_command -o file:exp_order grep '^Hook' stdout
 }
 
 
-atf_test_case fetch__hooks__pre_fail
-fetch__hooks__pre_fail_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test fetch__hooks__pre_fail
+fetch__hooks__pre_fail_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 XSRCDIR="$(pwd)/checkout/xsrc"
 
@@ -1042,25 +1145,26 @@ post_fetch_hook() {
 }
 EOF
 
-    atf_check -s exit:1 -o save:stdout -e save:stderr \
+    assert_command -s exit:1 -o save:stdout -e save:stderr \
         sysbuild -c test.conf fetch
     grep 'pre_fetch_hook returned an error' stderr || \
-        atf_fail "pre_fetch_hook didn't seem to fail"
-    test ! -f checkout/src/file-in-src || atf_fail "src checked out"
-    test ! -f checkout/xsrc/file-in-xsrc || atf_fail "xsrc checked out"
+        fail "pre_fetch_hook didn't seem to fail"
+    test ! -f checkout/src/file-in-src || fail "src checked out"
+    test ! -f checkout/xsrc/file-in-xsrc || fail "xsrc checked out"
 
     cat >exp_order <<EOF
 Hook before fetch
 EOF
-    atf_check -o file:exp_order grep '^Hook' stdout
+    assert_command -o file:exp_order grep '^Hook' stdout
 }
 
 
-atf_test_case fetch__hooks__post_fail
-fetch__hooks__post_fail_body() {
-    create_mock_cvsroot "${MOCK_CVSROOT}"
+shtk_unittest_add_test fetch__hooks__post_fail
+fetch__hooks__post_fail_test() {
+    mock_cvsroot=":local:$(pwd)/cvsroot"
+    create_mock_cvsroot "${mock_cvsroot}"
     cat >test.conf <<EOF
-CVSROOT="${MOCK_CVSROOT}"
+CVSROOT="${mock_cvsroot}"
 SRCDIR="$(pwd)/checkout/src"
 XSRCDIR="$(pwd)/checkout/xsrc"
 
@@ -1074,103 +1178,66 @@ post_fetch_hook() {
 }
 EOF
 
-    atf_check -s exit:1 -o save:stdout -e save:stderr \
+    assert_command -s exit:1 -o save:stdout -e save:stderr \
         sysbuild -c test.conf fetch
-    test -f checkout/src/file-in-src || atf_fail "src not checked out"
-    test -f checkout/xsrc/file-in-xsrc || atf_fail "xsrc not checked out"
+    test -f checkout/src/file-in-src || fail "src not checked out"
+    test -f checkout/xsrc/file-in-xsrc || fail "xsrc not checked out"
     grep 'post_fetch_hook returned an error' stderr || \
-        atf_fail "post_fetch_hook didn't seem to fail"
+        fail "post_fetch_hook didn't seem to fail"
 
     cat >exp_order <<EOF
 Hook before fetch
 Hook after fetch
 EOF
-    atf_check -o file:exp_order grep '^Hook' stdout
+    assert_command -o file:exp_order grep '^Hook' stdout
 }
 
 
-atf_test_case fetch__too_many_args
-fetch__too_many_args_body() {
+shtk_unittest_add_test fetch__too_many_args
+fetch__too_many_args_test() {
     cat >experr <<EOF
 sysbuild: E: fetch does not take any arguments
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -e file:experr sysbuild -c /dev/null fetch foo
+    assert_command -s exit:1 -e file:experr sysbuild -c /dev/null fetch foo
 }
 
 
-atf_test_case no_command
-no_command_body() {
+shtk_unittest_add_test no_command
+no_command_test() {
     cat >experr <<EOF
 sysbuild: E: No command specified
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -e file:experr sysbuild
+    assert_command -s exit:1 -e file:experr sysbuild
 }
 
 
-atf_test_case unknown_command
-unknown_command_body() {
+shtk_unittest_add_test unknown_command
+unknown_command_test() {
     cat >experr <<EOF
 sysbuild: E: Unknown command foo
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -e file:experr sysbuild foo
+    assert_command -s exit:1 -e file:experr sysbuild foo
 }
 
 
-atf_test_case unknown_flag
-unknown_flag_body() {
+shtk_unittest_add_test unknown_flag
+unknown_flag_test() {
     cat >experr <<EOF
 sysbuild: E: Unknown option -Z
 Type 'man sysbuild' for help
 EOF
-    atf_check -s exit:1 -e file:experr sysbuild -Z
+    assert_command -s exit:1 -e file:experr sysbuild -Z
 }
 
 
-atf_init_test_cases() {
-    atf_add_test_case build__custom_dirs
-    atf_add_test_case build__defaults
-    atf_add_test_case build__remove_all
-    atf_add_test_case build__fast_mode
-    atf_add_test_case build__many_machines
-    atf_add_test_case build__machine_targets__ok
-    atf_add_test_case build__machine_targets__unmatched
-    atf_add_test_case build__mkvars
-    atf_add_test_case build__with_x11
-    atf_add_test_case build__some_args
-    atf_add_test_case build__hooks__ok
-    atf_add_test_case build__hooks__pre_fail
-    atf_add_test_case build__hooks__post_fail
-    atf_add_test_case build__cvs_fails
-
-    atf_add_test_case config__builtins
-    atf_add_test_case config__path__components
-    atf_add_test_case config__path__extension
-    atf_add_test_case config__name__system_directory
-    atf_add_test_case config__name__user_directory
-    atf_add_test_case config__name__not_found
-    atf_add_test_case config__overrides
-    atf_add_test_case config__too_many_args
-
-    atf_add_test_case env__src_only
-    atf_add_test_case env__src_and_xsrc
-    atf_add_test_case env__explicit_machine
-    atf_add_test_case env__eval
-    atf_add_test_case env__too_many_machines
-    atf_add_test_case env__too_many_args
-
-    atf_add_test_case fetch__checkout__src_only
-    atf_add_test_case fetch__checkout__src_and_xsrc
-    atf_add_test_case fetch__update__src_only
-    atf_add_test_case fetch__update__src_and_xsrc
-    atf_add_test_case fetch__hooks__ok
-    atf_add_test_case fetch__hooks__pre_fail
-    atf_add_test_case fetch__hooks__post_fail
-    atf_add_test_case fetch__too_many_args
-
-    atf_add_test_case no_command
-    atf_add_test_case unknown_command
-    atf_add_test_case unknown_flag
+shtk_unittest_add_test missing_argument
+missing_argument_test() {
+    cat >experr <<EOF
+sysbuild: E: Missing argument to option -o
+Type 'man sysbuild' for help
+EOF
+    assert_command -s exit:1 -e file:experr sysbuild -o
 }
